import { Point, RGBAColor, Shader } from "./types";
/**
 * @throws Error if the number of colors is greater than MAX_COLOR_STOPS
 * @throws Error if stops is provided and is not the same length as stops
 * @throws Error if stops is provided and is not in ascending order
 */
export declare function radialGradient(options: {
    /**
     * The colors to use in the gradient. Must be at least 2.
     */
    colors: RGBAColor[];
    /**
     * An array of positions for each color stop. Must be the same length as colors and in ascending order.
     * If not provided, the stops will be evenly spaced.
     * @example [0, 0.5, 1]
     */
    stops?: RGBAColor[];
    /**
     * If true, the gradient will be circular. Similar to CSS radial-gradient circle parameter.
     * @default false
     */
    circle?: boolean;
    /**
     * The center of the gradient. Defaults to center
     * @example [0.5, 0.5]
     */
    center?: Point;
    /**
     * The scale of the gradient.
     * @default 1
     */
    scale?: number;
}): Shader;
